@@ -9,7 +9,7 @@
 #' @return Mallet model
 #' @importFrom textmineR Dtm2Docs CalcGamma
 #' @importFrom stats setNames
-#' @importFrom mallet mallet.top.words mallet.doc.topics mallet.word.freqs mallet.topic.labels MalletLDA  mallet.import  mallet.topic.words
+# @importFrom mallet mallet.top.words mallet.doc.topics mallet.word.freqs mallet.topic.labels MalletLDA  mallet.import  mallet.topic.words
 #' @importFrom utils combn
 #' @noRd
 get_mallet_model <- function(
@@ -19,6 +19,13 @@ get_mallet_model <- function(
     num_iterations = 1000, 
     seed){
   
+  
+  if (!requireNamespace("mallet", quietly = TRUE)) {
+    stop(paste0("JAVA and the R-packages 'rJava' and 'mallet' are required but one or more are not installed. \n", 
+                "Please install JAVA from https://www.java.com/. \n", 
+                "And then run install.packages(c('mallet', 'rJava')."))
+  }
+  
   docs <- textmineR::Dtm2Docs(dtm)
   
   model <- mallet::MalletLDA(
@@ -307,6 +314,14 @@ topicsModel <- function(
     num_iterations = 1000,
     seed = 42){
   
+  
+  if (!requireNamespace("mallet", quietly = TRUE)) {
+    stop(paste0("JAVA and the R-packages 'rJava' and 'mallet' are required but one or more are not installed. \n", 
+                "Please install JAVA from https://www.java.com/. \n", 
+                "And then run install.packages(c('mallet', 'rJava')."))
+  }
+  
+  
   set.seed(seed)
   
   dtm_settings <- dtm$settings
@@ -398,6 +413,11 @@ topicsPreds <- function(
     create_new_dtm = FALSE
     ){
   
+  if (!requireNamespace("mallet", quietly = TRUE)) {
+    stop(paste0("JAVA and the R-packages 'rJava' and 'mallet' are required but one or more are not installed. \n", 
+                "Please install JAVA from https://www.java.com/. \n", 
+                "And then run install.packages(c('mallet', 'rJava')."))
+  }
   set.seed(seed)
     
     if (length(data) == 0){
